@@ -173,7 +173,7 @@ class DataAccess:
 
             if response.status_code != 200:
                 raw = json.loads(response.text)
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             else:
                 raw_data = json.loads(response.text)['data']
                 df_raw = pd.DataFrame(raw_data)
@@ -200,7 +200,7 @@ class DataAccess:
 
             if response.status_code != 200:
                 raw = json.loads(response.text)
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             else:
                 raw_data = json.loads(response.text)['data']
                 return raw_data
@@ -223,7 +223,7 @@ class DataAccess:
 
             if response.status_code != 200:
                 raw = json.loads(response.text)
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             else:
                 raw_data = json.loads(response.text)['data']
                 return raw_data
@@ -264,9 +264,9 @@ class DataAccess:
                     response = requests.request(param, url, headers=header, data=payload, verify=False)
                     raw = json.loads(response.text)
                     if response.status_code != 200:
-                        raise ValueError(raw['error'])
+                        raise ValueError(raw)
                     if 'success' in raw:
-                        raise ValueError(raw['error'])
+                        raise ValueError(raw)
                     if len(json.loads(response.text)) == 0:
                         raise ValueError('No Data!')
                     else:
@@ -291,9 +291,9 @@ class DataAccess:
                     response = requests.request(param, url, headers=header, data=payload, verify=False)
                     raw = json.loads(response.text)
                     if response.status_code != 200:
-                        raise ValueError(raw['error'])
+                        raise ValueError(raw)
                     if 'success' in raw:
-                        raise ValueError(raw['error'])
+                        raise ValueError(raw)
                     elif len(json.loads(response.text)) == 0:
                         raise ValueError('No Data!')
                     else:
@@ -337,9 +337,9 @@ class DataAccess:
                     response = requests.request("GET", url, headers=header, data=payload)
                     raw = json.loads(response.text)
                     if response.status_code != 200:
-                        raise ValueError(raw['error'])
+                        raise ValueError(raw)
                     if 'success' in raw:
-                        raise ValueError(raw['error'])
+                        raise ValueError(raw)
                     if len(json.loads(response.text)['data']) == 0:
                         raise ValueError('No Data!')
                     else:
@@ -407,9 +407,9 @@ class DataAccess:
             response = requests.request("GET", temp, headers=header, data=payload)
             raw = json.loads(response.text)
             if response.status_code != 200:
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             if 'success' in raw:
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             if len(json.loads(response.text)['data']) == 0:
                 raise ValueError('No Data!')
             else:
@@ -470,7 +470,7 @@ class DataAccess:
 
             if response.status_code != 200:
                 raw = json.loads(response.text)
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             else:
                 raw_data = json.loads(response.text)['data']
                 return raw_data
@@ -502,7 +502,7 @@ class DataAccess:
 
             if response.status_code != 200:
                 raw = json.loads(response.text)
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             else:
                 raw_data = json.loads(response.text)['data']
                 return raw_data
@@ -532,7 +532,7 @@ class DataAccess:
 
             if response.status_code != 200:
                 raw = json.loads(response.text)
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             else:
                 raw_data = json.loads(response.text)
                 return raw_data
@@ -557,7 +557,7 @@ class DataAccess:
 
             if response.status_code != 200:
                 raw = json.loads(response.text)
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             else:
                 raw_data = json.loads(response.text)['data']
                 return raw_data
